@@ -79,12 +79,12 @@ class AfterAccumulatedDepthElement(Element):
                     new_price = place_above.price + adjustment
 
             if new_price is None:
-                self.logger.debug(f"""Order change - no acceptable depth for quantity {depth} so removing:
+                self._logger.debug(f"""Order change - no acceptable depth for quantity {depth} so removing:
     Old: {order}
     New: None""")
             else:
                 new_order: mango.Order = order.with_price(new_price)
-                self.logger.debug(f"""Order change - accumulated depth of {depth} is {self.adjustment_ticks} tick from {new_price}:
+                self._logger.debug(f"""Order change - accumulated depth of {depth} is {self.adjustment_ticks} tick from {new_price}:
     Old: {order}
     New: {new_order}""")
                 new_orders += [new_order]
@@ -93,4 +93,4 @@ class AfterAccumulatedDepthElement(Element):
 
     def __str__(self) -> str:
         depth: str = f"{self.depth}" if self.depth is not None else "order quantity"
-        return f"« 𝙰𝚏𝚝𝚎𝚛𝙰𝚌𝚌𝚞𝚖𝚞𝚕𝚊𝚝𝚎𝚍𝙳𝚎𝚙𝚝𝚑𝙴𝚕𝚎𝚖𝚎𝚗𝚝 [depth: {depth}, adjustment ticks: {self.adjustment_ticks}] »"
+        return f"« AfterAccumulatedDepthElement [depth: {depth}, adjustment ticks: {self.adjustment_ticks}] »"
